#
# spec file for package clone-master-clean-up
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clone-master-clean-up
Version:        1.12
Release:        1.3
Summary:        Tool to clean up a system for cloning preparation
License:        GPL-2.0-or-later
Group:          System/Management
URL:            https://www.suse.com
Source0:        clone-master-clean-up.sh
Source1:        clone-master-clean-up.1
Source2:        sysconfig.clone-master-clean-up
Source3:        custom_remove.template
Source10:       LICENSE
Source11:       README.md
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       coreutils
Requires:       curl
Requires:       sed
Requires:       systemd
Requires(post): %fillup_prereq
BuildArch:      noarch

%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%description
A tool to clean up a system for cloning preparation by cleaning up
usage history and log files, etc.

%prep

%build
cp %{S:10} %{S:11} .

%install
mkdir -p %{buildroot}%{_sbindir}
install -m700 %{S:0} %{buildroot}/%{_sbindir}/clone-master-clean-up
# manpage
mkdir -p %{buildroot}%{_mandir}/man1
install -m644 %{S:1} %{buildroot}/%{_mandir}/man1/clone-master-clean-up.1
# sysconfig file
mkdir -p %{buildroot}%{_fillupdir}
install -m644 %{S:2} %{buildroot}/%{_fillupdir}/sysconfig.clone-master-clean-up
# template
mkdir -p %{buildroot}/%{_datadir}/%{name}/
install -m644 %{S:3} %{buildroot}/%{_datadir}/%{name}/custom_remove.template
# custom_remove file location
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/

%post
%fillup_only -n clone-master-clean-up

%files
%doc README.md
%license LICENSE
%{_sbindir}/*
%{_mandir}/man1/*
%{_fillupdir}/*
%dir %{_datadir}/%{name}
%dir %{_sysconfdir}/%{name}
%{_datadir}/%{name}/custom_remove.template
%ghost %config %{_sysconfdir}/%{name}/custom_remove

%changelog
* Tue Mar 19 2024 Peter Varkoly <varkoly@suse.com>
- Error message about 'journald.conf' (bsc#1221533)
  Check if journald.conf does exist.
- 1.12
* Tue Feb  7 2023 Peter Varkoly <varkoly@suse.com>
- Bump version to 1.11
- clone-master-clean-up fails when /etc/iscsi/initiatorname.iscsi doesn't exist
  The entire section is wrapped in a test for the existence of this file.
  (bsc#1207993)
* Fri Oct 28 2022 Peter Varkoly <varkoly@suse.com>
- Bump version to 1.10
- clone-master-clean-up fails if postfix is not installed (bsc#1204835)
  Check if the directory does exists.
* Fri Sep 23 2022 Peter Varkoly <varkoly@suse.com>
- Bump version to 1.9
- [clone-master-clean-up] Cleannup initiatorname.iscsi
  Remove all no comment files
  (bsc#1203024)
* Thu Sep 22 2022 Peter Varkoly <varkoly@suse.com>
- Bump version to 1.8
- clone-master-clean-up fails to remove btrfs snapshots
  (bsc#1203651)
* Tue Aug 30 2022 abriel@suse.com
- Bump version to 1.7
- CVE-2021-32000: fix some potentially dangerous file system
  operations
  (bsc#1181050)
* Wed Aug 12 2020 abriel@suse.com
- Bump version to 1.6
- cleanup salt client ID and osad authentication configuration
  file and the system ID
  (bsc#1174147)
- change the path of the template file in the comments of
  custom_remove.template and clone-master-clean-up.sh
  (jsc#TEAM-490)
* Tue Oct  8 2019 abriel@suse.com
- Bump version to 1.5
- Don't show output from pushd/popd
- Make snapper snapshot removal more generic
  The output format is not really meant for machine reading, it's
  format has changed thus the simple parser broke.
  This now makes the parser more generic (using data from d-bus),
  also now it is ensured the snapshots are deleted in the correct
  order.
  (bsc#1149322)
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in descriptions.
* Wed Aug  7 2019 Egbert Eich <eich@suse.com>
- Install README.md and license file, fix build warnings.
- Fix _service-file:
  * Replace 'HEAD' version by 'master' branch:
    Right now, this project has just one single branch - track
    this as the release branch.
  * Add <versionformat>.
* Fri Aug  2 2019 Egbert Eich <eich@suse.com>
- Add _service file to fetch package form git.
  Add workaround for service osc_scm: avoid script to have the
  same name repository.
* Thu Aug  1 2019 eich@suse.com
- Wicked stores a number of files containing unique IDs and DHCP data
  in /var/lib/wicked/*. These files need to be removed for cloning:
  if machines with identical settings exist in the same network
  multiple times, IP addresses may change with each renewal
  (bsc#1139667)
* Wed Jan 30 2019 dakechi@suse.com
- Moved the configuration files out of the /var directory
  * Needed for compliance with transactional updates (bsc#1092378)
* Thu Feb  1 2018 ro@suse.de
- Prepare for new fillup location
* Thu Jul  6 2017 abriel@suse.com
- The following changes are made to accomplish FATE#322066
  * Fix typos and improve man page
* Mon May 15 2017 abriel@suse.com
- The following changes are made to accomplish FATE#322066
  * remove some more files and directories (see man page for detailes)
  * add clone-master-clean-up.sysconfig, to give the user the possibillity for minimal intervention
  * add custom_remove.template to allow partner or customer specific removals
* Fri Jan 15 2016 hguo@suse.com
- The following issues are addressed:
  * After wiping swap, the swap gets a new UUID, causing slow boot.
  * 70-persistent-net.rules is not removed.
  Along with several coding style and indentation fixes.
  (bsc#961906)
* Thu Dec 10 2015 varkoly@suse.com
- according to comment from Berthold Gunreben in comment #18 in
- FATE#318965 Allow Clone-Master creation, the random-seed files
- need to be deleted, too
* Fri Oct 23 2015 hguo@suse.com
- Add clean up item: auto-generated HANA firewall script.
* Mon Sep 14 2015 hguo@suse.com
- Initial version, initial release.
